@@ -1,8 +1,10 @@
-from typing import List
+from typing import List, Set
 
+from pied_poker.hand.base_hand import BaseHand
 from pied_poker.card.card import Card
 from pied_poker.card.rank import Rank
-from pied_poker.hand import BaseHand
+# from pied_poker.hand.base_hand import BaseHand
+from pied_poker.hand.straight_flush import StraightFlush
 
 
 class RoyalFlush(BaseHand):
@@ -52,4 +54,14 @@ class RoyalFlush(BaseHand):
     def __hash__(self):
         return hash(str(self))
 
+    def __hand_outs__(self, out_cards: Set[Card]) -> List[Card]:
+        rv = []
+
+        for straight_flush_out in self.as_hand(StraightFlush).__hand_outs__({*out_cards}, True):
+            hand = BaseHand(self.cards_sorted + [straight_flush_out]).as_hand(RoyalFlush)
+            if hand.is_hand:
+                rv.append(straight_flush_out)
+                out_cards.update({straight_flush_out})
+        return rv
+
 
