@@ -1,7 +1,7 @@
-from typing import List
+from typing import List, Set, Generic
 
 from pied_poker.card.card import Card
-from pied_poker.hand import BaseHand
+from pied_poker.hand import BaseHand, Flush
 
 
 class StraightFlush(BaseHand):
@@ -50,3 +50,14 @@ class StraightFlush(BaseHand):
 
     def __hash__(self):
         return hash(str(self))
+
+    def __hand_outs__(self, out_cards: Set[Card], include_higher_hand_outs=False) -> List[Card]:
+        rv = []
+        for flushOut in self.as_hand(Flush).__hand_outs__({*out_cards}, True):
+            newHand = BaseHand(self.cards_sorted + [flushOut]).as_hand(StraightFlush)
+            if newHand.is_hand and flushOut not in out_cards:
+                if newHand.__class__.hand_rank == StraightFlush.hand_rank or \
+                        (newHand.hand_rank > self.hand_rank and include_higher_hand_outs):
+                    rv.append(flushOut)
+                    out_cards.update([flushOut])
+        return rv
