@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Set
 
 from pied_poker.card.card import Card
 from pied_poker.hand.poker_hand import PokerHand
