@@ -20,13 +20,11 @@ class PlayerWinsWithTie(BasePokerEvent):
 
         # This will inherently include ties
         r = self.player in round_result.winners
-        r = r and len(round_result.winners > 1)
+        r = r and len(round_result.winners) > 1
         return r
 
     def __str__(self):
-        if self.includes_tie:
-            return f'{self.__class__.__name__}: Includes Tie'
-        return f'{self.__class__.__name__}: Does NOT Include Tie'
+        return f'{self.__class__.__name__}'
 
     def __repr__(self):
         return str(self)
